@@ -158,14 +158,28 @@ def makedir(dirname):
 def deepcopy(file_list, folder, replace = None):
 
     if isinstance(file_list, FileList):
-        file_list = file_list.get()
+        file_list = file_list.get(True)
     elif isinstance(file_list, str):
-        file_list = [file_list]
+        file_list = [(file_list, '')]
+    else:
+        result = []
+        for f in file_list:
+            result.append( ( f, ''))
+        file_list = result
+        del result
 
     stat = 0
     console.header( "- copy to %s (%s files)" % (folder, len(file_list)))
-    for file in file_list:
-        dst_file = os.path.join(folder,os.path.basename(file))
+    for (file, basepath) in file_list:
+        
+        if basepath:
+            dst_file = file.replace(basepath, '').strip('/')
+            dst_file = os.path.join(folder,dst_file)
+        else:
+            dst_file = os.path.join(folder,os.path.basename(file))
+
+        console.warn("File : " + file +  " dest " + dst_file)
+
         res = updatefile(file, dst_file)
 
 
